@@ -16,12 +16,14 @@
 
 set -eux -o pipefail
 
+GH_VERSION="2.21.2"
+
 echo "Installing latest version of gh"
-curl -qLO "https://github.com/cli/cli/releases/download/v1.6.2/gh_1.6.2_linux_amd64.tar.gz"  
-tar -xf gh_1.6.2_linux_amd64.tar.gz &&
-sudo mv gh_1.6.2_linux_amd64/bin/gh /usr/local/bin/gh
-rm gh_1.6.2_linux_amd64.tar.gz
-rm -rf gh_1.6.2_linux_amd64
+curl -qLO "https://github.com/cli/cli/releases/download/v${GH_VERSION}/gh_${GH_VERSION}_linux_amd64.tar.gz"
+tar -xf "gh_${GH_VERSION}_linux_amd64.tar.gz" &&
+sudo mv "gh_${GH_VERSION}_linux_amd64/bin/gh" /usr/local/bin/gh
+rm "gh_${GH_VERSION}_linux_amd64.tar.gz"
+rm -rf "gh_${GH_VERSION}_linux_amd64"
 
 echo "Authorizing bot with gh"
 echo "${access_token}" | gh auth login --with-token
