@@ -17,8 +17,10 @@ limitations under the License.
 package main
 
 import (
+	"fmt"
 	"io"
 	"net/http"
+	"os"
 	"strings"
 
 	"k8s.io/klog/v2"
@@ -93,6 +95,21 @@ var (
 				`GO_VERSION: .*`: `GO_VERSION: '{{.StableVersion}}'`,
 			},
 		},
+		".github/workflows/update-gh-version.yml": {
+			Replace: map[string]string{
+				`GO_VERSION: .*`: `GO_VERSION: '{{.StableVersion}}'`,
+			},
+		},
+		".github/workflows/update-docsy-version.yml": {
+			Replace: map[string]string{
+				`GO_VERSION: .*`: `GO_VERSION: '{{.StableVersion}}'`,
+			},
+		},
+		".github/workflows/update-hugo-version.yml": {
+			Replace: map[string]string{
+				`GO_VERSION: .*`: `GO_VERSION: '{{.StableVersion}}'`,
+			},
+		},
 		".github/workflows/time-to-k8s-public-chart.yml": {
 			Replace: map[string]string{
 				`GO_VERSION: .*`: `GO_VERSION: '{{.StableVersion}}'`,
@@ -123,6 +140,7 @@ var (
 				// searching for 1.* so it does NOT match "KVM_GO_VERSION ?= $(GO_VERSION:.0=)" in the Makefile
 				`GO_VERSION \?= 1.*`:             `GO_VERSION ?= {{.StableVersion}}`,
 				`GO_K8S_VERSION_PREFIX \?= v1.*`: `GO_K8S_VERSION_PREFIX ?= {{.K8SVersion}}`,
+				`GO_VERSION=[0-9.]+`:             `GO_VERSION={{.StableVersion}}`,
 			},
 		},
 		"hack/jenkins/installers/check_install_golang.sh": {
@@ -135,6 +153,16 @@ var (
 				`GoVersion = ".*"`: `GoVersion = "{{.StableVersion}}"`,
 			},
 		},
+		"deploy/kicbase/Dockerfile": {
+			Replace: map[string]string{
+				`golang:[0-9.]+`: `golang:{{.StableVersion}}`,
+			},
+		},
+		"deploy/addons/auto-pause/Dockerfile": {
+			Replace: map[string]string{
+				`golang:.*`: `golang:{{.StableVersion}}`,
+			},
+		},
 	}
 )
 
@@ -161,9 +189,13 @@ func main() {
 	klog.Infof("Golang stable version: %s", data.StableVersion)
 
 	update.Apply(schema, data)
+
+	if err := updateGoHashFile(stable); err != nil {
+		klog.Fatalf("failed to update go hash file: %v", err)
+	}
 }
 
-// goVersion returns Golang stable version.
+// goVersions returns Golang stable version.
 func goVersions() (stable, stableMM, k8sVersion string, err error) {
 	// will update to the same image that kubernetes project uses
 	resp, err := http.Get("https://raw.githubusercontent.com/kubernetes/kubernetes/master/build/build-image/cross/VERSION")
@@ -183,3 +215,24 @@ func goVersions() (stable, stableMM, k8sVersion string, err error) {
 	stableMM = strings.Join(mmp[0:2], ".") // <major>.<minor> version
 	return stable, stableMM, k8sVersion, nil
 }
+
+func updateGoHashFile(version string) error {
+	r, err := http.Get(fmt.Sprintf("https://dl.google.com/go/go%s.src.tar.gz.sha256", version))
+	if err != nil {
+		return fmt.Errorf("failed to download golang sha256 file: %v", err)
+	}
+	defer r.Body.Close()
+	sha, err := io.ReadAll(r.Body)
+	if err != nil {
+		return fmt.Errorf("failed to read response body: %v", err)
+	}
+	f, err := os.OpenFile("../../../deploy/iso/minikube-iso/go.hash", os.O_APPEND|os.O_WRONLY, 0644)
+	if err != nil {
+		return fmt.Errorf("failed to open go.hash file: %v", err)
+	}
+	defer f.Close()
+	if _, err := f.WriteString(fmt.Sprintf("sha256  %s  go%s.src.tar.gz\n", sha, version)); err != nil {
+		return fmt.Errorf("failed to write to go.hash file: %v", err)
+	}
+	return nil
+}
