@@ -19,8 +19,6 @@ package main
 import (
 	"bytes"
 	"context"
-	"errors"
-	"flag"
 	"fmt"
 	"io"
 	"net/http"
@@ -30,6 +28,7 @@ import (
 	"text/template"
 	"time"
 
+	"github.com/google/go-github/v43/github"
 	"golang.org/x/mod/semver"
 	"k8s.io/klog/v2"
 	"k8s.io/minikube/hack/update"
@@ -57,28 +56,39 @@ type Data struct {
 }
 
 func main() {
+	minver := constants.OldestKubernetesVersion
 
-	inputVersion := flag.Lookup("kubernetes-version").Value.String()
+	releases := []string{}
 
-	imageVersions := make([]string, 0)
+	ghc := github.NewClient(nil)
 
-	// set a context with defined timeout
-	ctx, cancel := context.WithTimeout(context.Background(), cxTimeout)
-	defer cancel()
-	if inputVersion == "latest" {
-		stableImageVersion, latestImageVersion, edgeImageVersion, err := getK8sVersions(ctx, "kubernetes", "kubernetes")
+	opts := &github.ListOptions{PerPage: 100}
+	for {
+		rls, resp, err := ghc.Repositories.ListReleases(context.Background(), "kubernetes", "kubernetes", opts)
 		if err != nil {
 			klog.Fatal(err)
 		}
-		uniqueMM := filterLatestUniqueMM([]string{stableImageVersion, latestImageVersion, edgeImageVersion})
-		imageVersions = append(imageVersions, uniqueMM...)
-	} else if semver.IsValid(inputVersion) {
-		imageVersions = append(imageVersions, inputVersion)
-	} else {
-		klog.Fatal(errors.New("invalid version"))
+		for _, rl := range rls {
+			ver := rl.GetTagName()
+			if !semver.IsValid(ver) {
+				continue
+			}
+			// skip out-of-range versions
+			if minver != "" && semver.Compare(minver, ver) == 1 {
+				continue
+			}
+			releases = append([]string{ver}, releases...)
+		}
+		if resp.NextPage == 0 {
+			break
+		}
+		opts.Page = resp.NextPage
 	}
 
-	for _, imageVersion := range imageVersions {
+	for _, imageVersion := range releases {
+		if _, ok := constants.KubeadmImages[imageVersion]; ok {
+			continue
+		}
 		imageMapString, err := getKubeadmImagesMapString(imageVersion)
 		if err != nil {
 			klog.Fatalln(err)
@@ -91,39 +101,13 @@ func main() {
 			},
 		}
 
-		majorMinorVersion := semver.MajorMinor(imageVersion)
-
-		if _, ok := constants.KubeadmImages[majorMinorVersion]; !ok {
-			data = Data{ImageMap: imageMapString}
-			schema[minikubeConstantsFilePath].Replace[`KubeadmImages = .*`] =
-				`KubeadmImages = map[string]map[string]string{ {{.ImageMap}}`
-		} else {
-			data = Data{ImageMap: strings.TrimLeft(imageMapString, "\n")}
-			versionIdentifier := fmt.Sprintf(`"%s": {[^}]+},`, majorMinorVersion)
-			schema[minikubeConstantsFilePath].Replace[versionIdentifier] = "{{.ImageMap}}"
-		}
-
+		data = Data{ImageMap: imageMapString}
+		schema[minikubeConstantsFilePath].Replace[`KubeadmImages = .*`] =
+			`KubeadmImages = map[string]map[string]string{ {{.ImageMap}}`
 		update.Apply(schema, data)
 	}
 }
 
-func filterLatestUniqueMM(versions []string) []string {
-	if len(versions) < 2 {
-		return versions
-	}
-	semver.Sort(versions)
-	uniqueMMVersions := []string{}
-	last := versions[0]
-	for _, ver := range versions {
-		if semver.MajorMinor(last) != semver.MajorMinor(ver) {
-			uniqueMMVersions = append(uniqueMMVersions, last)
-		}
-		last = ver
-	}
-	uniqueMMVersions = append(uniqueMMVersions, last)
-	return uniqueMMVersions
-}
-
 func getKubeadmImagesMapString(version string) (string, error) {
 	url := fmt.Sprintf(kubeadmReleaseURL, version)
 	fileName := fmt.Sprintf(kubeadmBinaryName, version)
@@ -149,8 +133,7 @@ func getKubeadmImagesMapString(version string) (string, error) {
 
 func formatKubeadmImageList(version, data string) (string, error) {
 	templateData := make(map[string]map[string]string)
-	majorMinorVersion := semver.MajorMinor(version)
-	templateData[majorMinorVersion] = make(map[string]string)
+	templateData[version] = make(map[string]string)
 	lines := strings.Split(data, "\n")
 	for _, line := range lines {
 		imageTag := strings.Split(line, ":")
@@ -161,7 +144,7 @@ func formatKubeadmImageList(version, data string) (string, error) {
 		imageName := strings.Split(imageTag[0], "/")
 		imageTag[0] = strings.Join(imageName[1:], "/")
 		if !isKubeImage(imageTag[0]) {
-			templateData[majorMinorVersion][imageTag[0]] = imageTag[1]
+			templateData[version][imageTag[0]] = imageTag[1]
 		}
 	}
 
@@ -221,18 +204,3 @@ func executeCommand(command string, args ...string) (string, error) {
 	}
 	return string(output), nil
 }
-
-// getK8sVersion returns Kubernetes versions.
-func getK8sVersions(ctx context.Context, owner, repo string) (stable, latest, edge string, err error) {
-	// get Kubernetes versions from GitHub Releases
-	stable, latest, edge, err = update.GHReleases(ctx, owner, repo)
-	if err != nil {
-		return "", "", "", err
-	}
-
-	if !semver.IsValid(stable) || !semver.IsValid(latest) || !semver.IsValid(edge) {
-		return "", "", "", fmt.Errorf("invalid release obtained stable : %s, latest : %s, edge: %s", stable, latest, edge)
-	}
-
-	return stable, latest, edge, nil
-}
