@@ -65,15 +65,12 @@ func HostIP(host *host.Host, clusterName string) (net.IP, error) {
 		if err != nil {
 			return []byte{}, errors.Wrap(err, "Error getting IP address")
 		}
-		// user network case
 		if ipString == "127.0.0.1" {
+			// user network case
 			return net.ParseIP("10.0.2.2"), nil
 		}
-		ip := net.ParseIP(ipString).To4()
-		if ip == nil {
-			return []byte{}, errors.Wrap(err, "Error converting IP address to IPv4 address")
-		}
-		return ip, nil
+		// socket_vmnet network case
+		return net.ParseIP("192.168.105.1"), nil
 	case driver.HyperV:
 		v := reflect.ValueOf(host.Driver).Elem()
 		var hypervVirtualSwitch string
