@@ -32,10 +32,10 @@ var (
 
 const (
 	// DefaultKubernetesVersion is the default Kubernetes version
-	DefaultKubernetesVersion = "v1.25.3"
+	DefaultKubernetesVersion = "v1.26.1"
 	// NewestKubernetesVersion is the newest Kubernetes version to test against
 	// NOTE: You may need to update coreDNS & etcd versions in pkg/minikube/bootstrapper/images/images.go
-	NewestKubernetesVersion = "v1.25.3"
+	NewestKubernetesVersion = "v1.26.1"
 	// OldestKubernetesVersion is the oldest Kubernetes version to test against
 	OldestKubernetesVersion = "v1.16.0"
 	// NoKubernetesVersion is the version used when users does NOT want to install kubernetes
@@ -54,6 +54,7 @@ const (
 	SSHPort = 22
 	// RegistryAddonPort os the default registry addon port
 	RegistryAddonPort = 5000
+
 	// Containerd is the default name and spelling for the containerd container runtime
 	Containerd = "containerd"
 	// CRIO is the default name and spelling for the cri-o container runtime
@@ -63,6 +64,12 @@ const (
 	// DefaultContainerRuntime is our default container runtime
 	DefaultContainerRuntime = ""
 
+	// cgroup drivers
+	DefaultCgroupDriver  = "systemd"
+	CgroupfsCgroupDriver = "cgroupfs"
+	SystemdCgroupDriver  = "systemd"
+	UnknownCgroupDriver  = ""
+
 	// APIServerName is the default API server name
 	APIServerName = "minikubeCA"
 	// ClusterDNSDomain is the default DNS domain
