@@ -25,7 +25,7 @@ import (
 	"time"
 
 	"github.com/hashicorp/go-getter"
-	"github.com/juju/mutex"
+	"github.com/juju/mutex/v2"
 	"github.com/pkg/errors"
 	"k8s.io/klog/v2"
 	"k8s.io/minikube/pkg/minikube/detect"
@@ -125,6 +125,7 @@ func lockDownload(file string) (mutex.Releaser, error) {
 
 	go func() {
 		spec := lock.PathMutexSpec(file)
+		spec.Timeout = 5 * time.Minute
 		releaser, err := mutex.Acquire(spec)
 		if err != nil {
 			lockChannel <- retPair{nil, errors.Wrapf(err, "failed to acquire lock \"%s\": %+v", file, spec)}
