@@ -20,42 +20,15 @@ import (
 	"encoding/binary"
 	"fmt"
 	"net"
-	"sync"
 	"time"
 
+	"github.com/juju/mutex/v2"
 	"k8s.io/klog/v2"
+	"k8s.io/minikube/pkg/util/lock"
 )
 
 const defaultReservationPeriod = 1 * time.Minute
 
-var (
-	reservedSubnets = sync.Map{}
-
-	// valid private network subnets (RFC1918)
-	privateSubnets = []net.IPNet{
-		// 10.0.0.0/8
-		{
-			IP:   []byte{10, 0, 0, 0},
-			Mask: []byte{255, 0, 0, 0},
-		},
-		// 172.16.0.0/12
-		{
-			IP:   []byte{172, 16, 0, 0},
-			Mask: []byte{255, 240, 0, 0},
-		},
-		// 192.168.0.0/16
-		{
-			IP:   []byte{192, 168, 0, 0},
-			Mask: []byte{255, 255, 0, 0},
-		},
-	}
-)
-
-// reservation of free private subnet is held for defined reservation period from createdAt time.
-type reservation struct {
-	createdAt time.Time
-}
-
 // Parameters contains main network parameters.
 type Parameters struct {
 	IP        string // IP address of network
@@ -66,7 +39,9 @@ type Parameters struct {
 	ClientMin string // second IP address
 	ClientMax string // last IP address before broadcast
 	Broadcast string // last IP address
+	IsPrivate bool   // whether the IP is private or not
 	Interface
+	reservation mutex.Releaser // subnet reservation has lifespan of the process: "If a process dies while the mutex is held, the mutex is automatically released."
 }
 
 // Interface contains main network interface parameters.
@@ -123,15 +98,12 @@ func lookupInInterfaces(ip net.IP) (*Parameters, *net.IPNet, error) {
 // inspect initialises IPv4 network parameters struct from given address addr.
 // addr can be single address (like "192.168.17.42"), network address (like "192.168.17.0") or in CIDR form (like "192.168.17.42/24 or "192.168.17.0/24").
 // If addr belongs to network of local network interface, parameters will also contain info about that network interface.
-func inspect(addr string) (*Parameters, error) {
+var inspect = func(addr string) (*Parameters, error) {
 
 	// extract ip from addr
-	ip, network, err := net.ParseCIDR(addr)
+	ip, network, err := ParseAddr(addr)
 	if err != nil {
-		ip = net.ParseIP(addr)
-		if ip == nil {
-			return nil, fmt.Errorf("failed parsing address %s: %w", addr, err)
-		}
+		return nil, err
 	}
 
 	n := &Parameters{}
@@ -161,6 +133,7 @@ func inspect(addr string) (*Parameters, error) {
 	n.Netmask = net.IP(network.Mask).String() // dotted-decimal format ('a.b.c.d')
 	n.Prefix, _ = network.Mask.Size()
 	n.CIDR = network.String()
+	n.IsPrivate = network.IP.IsPrivate()
 
 	networkIP := binary.BigEndian.Uint32(network.IP)                      // IP address of network
 	networkMask := binary.BigEndian.Uint32(network.Mask)                  // network mask
@@ -191,7 +164,7 @@ func inspect(addr string) (*Parameters, error) {
 
 // isSubnetTaken returns if local network subnet exists and any error occurred.
 // If will return false in case of an error.
-func isSubnetTaken(subnet string) (bool, error) {
+var isSubnetTaken = func(subnet string) (bool, error) {
 	ifAddrs, err := net.InterfaceAddrs()
 	if err != nil {
 		return false, fmt.Errorf("failed listing network interface addresses: %w", err)
@@ -208,16 +181,6 @@ func isSubnetTaken(subnet string) (bool, error) {
 	return false, nil
 }
 
-// isSubnetPrivate returns if subnet is private network.
-func isSubnetPrivate(subnet string) bool {
-	for _, ipnet := range privateSubnets {
-		if ipnet.Contains(net.ParseIP(subnet)) {
-			return true
-		}
-	}
-	return false
-}
-
 // IsUser returns if network is user.
 func IsUser(network string) bool {
 	return network == "user"
@@ -225,19 +188,21 @@ func IsUser(network string) bool {
 
 // FreeSubnet will try to find free private network beginning with startSubnet, incrementing it in steps up to number of tries.
 func FreeSubnet(startSubnet string, step, tries int) (*Parameters, error) {
+	currSubnet := startSubnet
 	for try := 0; try < tries; try++ {
-		n, err := inspect(startSubnet)
+		n, err := inspect(currSubnet)
 		if err != nil {
 			return nil, err
 		}
-		startSubnet = n.IP
-		if isSubnetPrivate(startSubnet) {
-			taken, err := isSubnetTaken(startSubnet)
+		subnet := n.IP
+		if n.IsPrivate {
+			taken, err := isSubnetTaken(subnet)
 			if err != nil {
 				return nil, err
 			}
 			if !taken {
-				if ok := reserveSubnet(startSubnet, defaultReservationPeriod); ok {
+				if reservation, err := reserveSubnet(subnet, defaultReservationPeriod); err == nil {
+					n.reservation = reservation
 					klog.Infof("using free private subnet %s: %+v", n.CIDR, n)
 					return n, nil
 				}
@@ -249,50 +214,37 @@ func FreeSubnet(startSubnet string, step, tries int) (*Parameters, error) {
 			klog.Infof("skipping subnet %s that is not private", n.CIDR)
 		}
 		prefix, _ := net.ParseIP(n.IP).DefaultMask().Size()
-		nextSubnet := net.ParseIP(startSubnet).To4()
+		nextSubnet := net.ParseIP(currSubnet).To4()
 		if prefix <= 16 {
 			nextSubnet[1] += byte(step)
 		} else {
 			nextSubnet[2] += byte(step)
 		}
-		startSubnet = nextSubnet.String()
+		currSubnet = nextSubnet.String()
 	}
 	return nil, fmt.Errorf("no free private network subnets found with given parameters (start: %q, step: %d, tries: %d)", startSubnet, step, tries)
 }
 
-// reserveSubnet returns if subnet was successfully reserved for given period:
-//   - false, if it already has unexpired reservation
-//   - true, if new reservation was created or expired one renewed
-//
-// uses sync.Map to manage reservations thread-safe
-func reserveSubnet(subnet string, period time.Duration) bool {
-	// put 'zero' reservation{} Map value for subnet Map key
-	// to block other processes from concurrently changing this subnet
-	zero := reservation{}
-	r, loaded := reservedSubnets.LoadOrStore(subnet, zero)
-	// check if there was previously issued reservation
-	if loaded {
-		// back off if previous reservation was already set to 'zero'
-		// as then other process is already managing this subnet concurrently
-		if r == zero {
-			klog.Infof("backing off reserving subnet %s (other process is managing it!): %+v", subnet, &reservedSubnets)
-			return false
+// ParseAddr will try to parse an ip or a cidr address
+func ParseAddr(addr string) (net.IP, *net.IPNet, error) {
+	ip, network, err := net.ParseCIDR(addr)
+	if err != nil {
+		ip = net.ParseIP(addr)
+		if ip == nil {
+			return nil, nil, fmt.Errorf("failed parsing address %s: %w", addr, err)
 		}
-		// check if previous reservation expired
-		createdAt := r.(reservation).createdAt
-		if time.Since(createdAt) < period {
-			// unexpired reservation: restore original createdAt value
-			reservedSubnets.Store(subnet, reservation{createdAt: createdAt})
-			klog.Infof("skipping subnet %s that has unexpired reservation: %+v", subnet, &reservedSubnets)
-			return false
-		}
-		// expired reservation: renew setting createdAt to now
-		reservedSubnets.Store(subnet, reservation{createdAt: time.Now()})
-		klog.Infof("reusing subnet %s that has expired reservation: %+v", subnet, &reservedSubnets)
-		return true
+		err = nil
 	}
-	// new reservation
-	klog.Infof("reserving subnet %s for %v: %+v", subnet, period, &reservedSubnets)
-	reservedSubnets.Store(subnet, reservation{createdAt: time.Now()})
-	return true
+	return ip, network, err
+}
+
+// reserveSubnet returns releaser if subnet was successfully reserved for given period, creating lock for subnet to avoid race condition between multiple minikube instances (especially while testing in parallel).
+var reserveSubnet = func(subnet string, period time.Duration) (mutex.Releaser, error) {
+	spec := lock.PathMutexSpec(subnet)
+	spec.Timeout = 1 * time.Millisecond // practically: just check, don't wait
+	reservation, err := mutex.Acquire(spec)
+	if err != nil {
+		return nil, err
+	}
+	return reservation, nil
 }
