@@ -1,5 +1,4 @@
 //go:build iso
-// +build iso
 
 /*
 Copyright 2016 The Kubernetes Authors All rights reserved.
@@ -28,7 +27,7 @@ import (
 	"k8s.io/minikube/pkg/minikube/vmpath"
 )
 
-// TestGuestEnvironment verifies files and packges installed inside minikube ISO/Base image
+// TestGuestEnvironment verifies files and packages installed inside minikube ISO/Base image
 func TestGuestEnvironment(t *testing.T) {
 	MaybeParallel(t)
 
@@ -37,14 +36,14 @@ func TestGuestEnvironment(t *testing.T) {
 	defer CleanupWithLogs(t, profile, cancel)
 
 	t.Run("Setup", func(t *testing.T) {
-		args := append([]string{"start", "-p", profile, "--install-addons=false", "--memory=2048", "--wait=false", "--disable-optimizations=true"}, StartArgs()...)
+		args := append([]string{"start", "-p", profile, "--install-addons=false", "--memory=2048", "--wait=false", "--disable-metrics=true"}, StartArgs()...)
 		rr, err := Run(t, exec.CommandContext(ctx, Target(), args...))
 		if err != nil {
 			t.Errorf("failed to start minikube: args %q: %v", rr.Command(), err)
 		}
 
 		if strings.Contains(rr.Stderr.String(), "kubelet.housekeeping-interval=5m") {
-			t.Error("--disable-optimizations=true is not working, optimizations found")
+			t.Error("--disable-metrics=true is not working, housekeeping interval not increased")
 		}
 	})
 
